@@ -1,4 +1,4 @@
-#$Id: Measurement.pm 480 2006-08-11 09:33:26Z schroeer $
+#$Id: Measurement.pm 495 2006-08-14 15:46:01Z schroeer $
 
 package Lab::Measurement;
 
@@ -10,7 +10,7 @@ use Lab::Data::Writer;
 use Lab::Data::Meta;
 use Lab::Data::Plotter;
 
-our $VERSION = sprintf("0.%04d", q$Revision: 480 $ =~ / (\d+) /);
+our $VERSION = sprintf("0.%04d", q$Revision$ =~ / (\d+) /);
 
 sub new {
     my $proto = shift;
@@ -55,7 +55,7 @@ sub new {
     $writer->log_comment("Sample $params{sample}");
     $writer->log_comment($params{title});
     $writer->log_comment($params{description});
-    $writer->log_comment('Recorded with $Id: Measurement.pm 480 2006-08-11 09:33:26Z schroeer $');
+    $writer->log_comment('Recorded with $Id: Measurement.pm 495 2006-08-14 15:46:01Z schroeer $');
         
     # Meta erzeugen
     my $meta=new Lab::Data::Meta({
@@ -302,7 +302,7 @@ where C<%config> can contain
   live_refresh  => '',
   live_latest   => '',
   
-  writer_config => {},  # Configuration options for L<Lab::Data::Writer|Lab::Data::Writer>
+  writer_config => {},  # Configuration options for Lab::Data::Writer
 
 =head1 METHODS
 
@@ -340,7 +340,7 @@ magic log. deprecated.
 
 =head1 AUTHOR/COPYRIGHT
 
-This is $Id: Measurement.pm 480 2006-08-11 09:33:26Z schroeer $
+This is $Id: Measurement.pm 495 2006-08-14 15:46:01Z schroeer $
 
 Copyright 2004-2006 Daniel Schrer (L<http://www.danielschroeer.de>)
 
